@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2016 Yoran Heling
+  Copyright (c) 2011-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -404,6 +404,12 @@ static const doc_set_t doc_sets[] = {
   "Minimum segment size to use when requesting file data from another user."
   " Set to 0 to disable segmented downloading."
 },
+{
+  "download_shared", 0, "<boolean>",
+  "Whether to download files which are already present in your share. When this"
+  " is set to `false', adding already shared files results in a UI message"
+  " instead of adding the file to the download queue."
+},
 { "download_slots", 0, "<integer>",
   "Maximum number of simultaneous downloads."
 },
@@ -439,13 +445,10 @@ static const doc_set_t doc_sets[] = {
   " your system for other things besides ncdc, you share large files (>100MB)"
   " and people are not constantly downloading the same file from you."
 },
-{ "geoip_cc4", 0, "<path>|disabled",
-  "Path to the GeoIP Country database file for IPv4, or 'disabled' to disable"
-  " GeoIP lookup for IPv4 addresses."
-},
-{ "geoip_cc6", 0, "<path>|disabled",
-  "Path to the GeoIP Country database file for IPv6, or 'disabled' to disable"
-  " GeoIP lookup for IPv6 addresses."
+{ "geoip_cc", 0, "<path>|disabled",
+  "Path to the GeoIP2 Country database file (GeoLite2-Country.mmdb), or"
+  " 'disabled' to disable GeoIP lookups. The database can be downloaded "
+  " from https://dev.maxmind.com/geoip/geoip2/geolite2/."
 },
 { "hash_rate", 0, "<speed>",
   "Maximum file hashing speed. See the `download_rate' setting for allowed"
@@ -559,6 +562,11 @@ static const doc_set_t doc_sets[] = {
   " enabled, any symlinks in your shared directories will be followed, even"
   " when they point to a directory outside your share."
 },
+{
+  "show_free_slots", 1, "<boolean>",
+  "When set to true, [n sl] will be prepended to your description, where n is"
+  " the number of currently available upload slots."
+},
 { "show_joinquit", 1, "<boolean>",
   "Whether to display join/quit messages in the hub chat."
 },
