@@ -1,6 +1,6 @@
 /* ncdc - NCurses Direct Connect client
 
-  Copyright (c) 2011-2016 Yoran Heling
+  Copyright (c) 2011-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -613,9 +613,8 @@ static char *i_ffc() {
 
 static gboolean s_geoip_cc(guint64 hub, const char *key, const char *val, GError **err) {
 #ifdef USE_GEOIP
-  int v = strcmp(key, "geoip_cc4") == 0 ? 4 : 6;
   db_vars_set(hub, key, val);
-  geoip_reinit(v);
+  geoip_reinit();
   return TRUE;
 #else
   g_set_error(err, 1, 0, "This option can't be modified: %s.", "Ncdc has not been compiled with GeoIP support");
@@ -962,14 +961,14 @@ struct var_t {
   V(download_exclude, 1,0, f_id,           p_regex,         su_old,        NULL,         NULL,            NULL)\
   V(download_rate,    1,0, f_speed,        p_speed,         NULL,          NULL,         NULL,            NULL)\
   V(download_segment, 1,0, f_download_segment,p_download_segment,NULL,     NULL,         NULL,            g_strdup_printf("%"G_GUINT64_FORMAT, (guint64)DLFILE_CHUNKSIZE))\
+  V(download_shared,  1,0, f_bool,         p_bool,          su_bool,       NULL,         NULL,            "true")\
   V(download_slots,   1,0, f_int,          p_int,           NULL,          NULL,         s_download_slots,"3")\
   V(email,            1,1, f_id,           p_id,            su_old,        NULL,         s_hubinfo,       NULL)\
   V(encoding,         1,1, f_id,           p_encoding,      su_encoding,   NULL,         NULL,            "UTF-8")\
   V(filelist_maxage,  1,0, f_interval,     p_interval,      su_old,        NULL,         NULL,            "604800")\
   V(fl_done,          0,0, NULL,           NULL,            NULL,          NULL,         NULL,            "false")\
   V(flush_file_cache, 1,0, f_ffc,          p_ffc,           su_ffc,        g_ffc,        s_ffc,           i_ffc())\
-  V(geoip_cc4,        1,0, f_id,           p_id,            su_path,       NULL,         s_geoip_cc,      NULL)\
-  V(geoip_cc6,        1,0, f_id,           p_id,            su_path,       NULL,         s_geoip_cc,      NULL)\
+  V(geoip_cc,         1,0, f_id,           p_id,            su_path,       NULL,         s_geoip_cc,      NULL)\
   V(hash_rate,        1,0, f_speed,        p_speed,         NULL,          NULL,         NULL,            NULL)\
   V(hubaddr,          0,0, NULL,           NULL,            NULL,          NULL,         NULL,            NULL)\
   V(hubkp,            0,0, NULL,           NULL,            NULL,          NULL,         NULL,            NULL)\
@@ -992,6 +991,7 @@ struct var_t {
   V(share_exclude,    1,0, f_id,           p_regex,         su_old,        NULL,         NULL,            NULL)\
   V(share_hidden,     1,0, f_bool,         p_bool,          su_bool,       NULL,         NULL,            "false")\
   V(share_symlinks,   1,0, f_bool,         p_bool,          su_bool,       NULL,         NULL,            "false")\
+  V(show_free_slots,  1,1, f_bool,         p_bool,          su_bool,       NULL,         s_hubinfo,       "false")\
   V(show_joinquit,    1,1, f_bool,         p_bool,          su_bool,       NULL,         NULL,            "false")\
   V(slots,            1,0, f_int,          p_int_ge1,       NULL,          NULL,         s_hubinfo,       "10")\
   V(sudp_policy,      1,0, f_sudp_policy,  p_sudp_policy,   su_sudp_policy,g_sudp_policy,s_sudp_policy,   G_STRINGIFY(VAR_SUDPP_PREFER))\
